@@ -426,6 +426,19 @@ def delete_user_permissions(ctx, user_id, resource_type):
     click.echo(f"Sucessfully deleted {resource_type} permissions for user {user_id}")
 
 
+@cli.command()
+@click.pass_context
+@click.option("--user-id", required=True, help="User to grant roles to.")
+@click.option(
+    "--role", required=True, multiple=True, help="Role to grant the user.",
+)
+def give_roles_to_user(ctx, user_id, role):
+    """Grant roles to a user."""
+    api = ctx.obj["api"]
+    api.give_roles_to_user(user_id, list(role))
+    click.echo(f"Successfully granted roles {role} to user {user_id}")
+
+
 def main():
     """Create command line application."""
     return cli(obj={})
